Brightway2 data management
==========================

.. image:: https://ci.appveyor.com/api/projects/status/uqixaochulbu6vjv?svg=true
   :target: https://ci.appveyor.com/project/cmutel/brightway2-data
   :alt: bw2data appveyor build status

.. image:: https://coveralls.io/repos/bitbucket/cmutel/brightway2-data/badge.svg?branch=master
    :target: https://coveralls.io/bitbucket/cmutel/brightway2-data?branch=default
    :alt: Test coverage report

This package provides tools for the management of inventory databases and impact assessment methods.
It is part of the `Brightway2 LCA framework <https://brightway.dev>`_.
`Online documentation <https://docs.brightway.dev/>`_ is available, and the source code is hosted on `GitHub brightway-lca organization <https://github.com/brightway-lca/brightway2-data>`_.
